summaryrefslogtreecommitdiffstats
path: root/src/demos/util
diff options
context:
space:
mode:
authorKenneth Russel <[email protected]>2005-08-06 19:59:40 +0000
committerKenneth Russel <[email protected]>2005-08-06 19:59:40 +0000
commit8ad7326f25441a437e4ab826596a20ffc0bddd5d (patch)
tree16ce0dc75d3f05acb3b5847b1b830799630e5be4 /src/demos/util
parente99aeb5f40422070161865bb1d37b9158e3de63f (diff)
Refactored nearly all demos as GLEventListeners and imported most into
JRefract framework. Deleted duplicate Gears code in fullscreen demos. git-svn-id: file:///usr/local/projects/SUN/JOGL/git-svn/../svn-server-sync/jogl-demos/branches/JSR-231@107 3298f667-5e0e-4b4a-8ed4-a3559d26a5f4
Diffstat (limited to 'src/demos/util')
-rwxr-xr-xsrc/demos/util/DemoListener.java8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/demos/util/DemoListener.java b/src/demos/util/DemoListener.java
index cbe7570..ee343e7 100755
--- a/src/demos/util/DemoListener.java
+++ b/src/demos/util/DemoListener.java
@@ -39,8 +39,12 @@
package demos.util;
-/** Defines how demos can request to be shut down. Different harnesses
- may respond differently to this event. */
+/** Defines certain events demos can send. Different harnesses
+ may respond differently to these events. */
public interface DemoListener {
+ /** Indicates that the demo wants to be terminated. */
public void shutdownDemo();
+
+ /** Indicates that a repaint should be scheduled later. */
+ public void repaint();
}